#[non_exhaustive]pub enum Htj2k97CodeBlockOptionsError {
NumericOptionsOutOfRange,
QuantizationOptionsOutOfRange,
DimensionExponentUnsupported {
axis: Htj2k97CodeBlockAxis,
exponent_minus_two: u8,
},
DimensionsExceedLimits {
width: usize,
height: usize,
},
}Expand description
Failure returned when shared HTJ2K 9/7 code-block options are unsupported.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NumericOptionsOutOfRange
Bit depth, guard bits, or the global quantization scale is unsupported.
QuantizationOptionsOutOfRange
A subband scale, derived delta, or declared bitplane count is unsupported.
DimensionExponentUnsupported
A dimension exponent cannot be represented by the host index type.
Fields

axis: Htj2k97CodeBlockAxisDimension whose exponent was rejected.
DimensionsExceedLimits
Decoded code-block dimensions exceed the HTJ2K side or area limit.
Implementations