#[non_exhaustive]pub enum TranscodeStageError {
Unsupported(&'static str),
Backend {
backend: &'static str,
operation: &'static str,
source: Box<dyn Error + Send + Sync + 'static>,
},
MemoryCapExceeded {
requested: usize,
cap: usize,
},
HostAllocationFailed {
bytes: usize,
},
DeviceMemoryCapExceeded {
backend: &'static str,
what: &'static str,
requested: usize,
cap: usize,
},
DeviceAllocationFailed {
backend: &'static str,
what: &'static str,
requested: usize,
},
DeviceUnavailable,
}Expand description
Error returned by accelerated transcode stage backends.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unsupported(&'static str)
The job shape, options, or environment are outside what this backend supports.
Backend
A backend accepted work and failed while executing it.
Fields
MemoryCapExceeded
The requested host workspace exceeds the shared process safety cap.
HostAllocationFailed
The host allocator could not reserve the requested workspace.
DeviceMemoryCapExceeded
A device allocation exceeds the backend’s checked safety cap.
Fields
DeviceAllocationFailed
A cap-valid device allocation failed.
Fields
The device or runtime backing this accelerator is unavailable.
Implementations