pub struct JpegToHtj2kOptions {
pub encode_options: JpegToHtj2kEncodeOptions,
pub coefficient_path: JpegToHtj2kCoefficientPath,
pub validate_against_float_reference: bool,
pub validate_against_integer_reference: bool,
}Expand description
Options for the experimental JPEG-to-HTJ2K path.
Fields
encode_options: JpegToHtj2kEncodeOptionsHTJ2K encode options used after wavelet bands are produced.
coefficient_path: JpegToHtj2kCoefficientPathCoefficient production path used for HTJ2K precomputed bands.
validate_against_float_reference: boolMaterialize the float IDCT-then-DWT oracle and report rounded coefficient differences. This is intended for validation and tests, not the production direct path.
validate_against_integer_reference: boolMaterialize signinum-jpeg scalar ISLOW samples and report reversible integer 5/3 coefficient differences against the rounded direct path. This is intended for validation and tests, not the production direct path.
Implementations
Sourceimpl JpegToHtj2kOptions
impl JpegToHtj2kOptions
Sourcepub fn lossless_53() -> JpegToHtj2kOptions
pub fn lossless_53() -> JpegToHtj2kOptions
Options for the default reversible 5/3 HTJ2K coefficient path.
Sourcepub fn lossy_97() -> JpegToHtj2kOptions
pub fn lossy_97() -> JpegToHtj2kOptions
Options for the irreversible 9/7 HTJ2K float-linear coefficient path.