pub struct TranscodePipelineStageReport {
pub stage: TranscodePipelineStageKind,
pub processor: TranscodeStageProcessor,
pub cpu_us: u128,
pub metal_us: u128,
pub transfer_us: u128,
pub dispatches: usize,
pub fallback_jobs: usize,
pub note: &'static str,
}Expand description
One stage in a transcode pipeline residency map.
Fields
stage: TranscodePipelineStageKindLogical transcode stage.
processor: TranscodeStageProcessorObserved CPU/Metal residency for this stage.
cpu_us: u128CPU/native time currently visible for this stage, in microseconds.
metal_us: u128Metal/accelerator time currently visible for this stage, in microseconds.
transfer_us: u128Host/device transfer time visible for this stage, in microseconds.
dispatches: usizeDispatches observed for this stage.
fallback_jobs: usizeComponent jobs that used CPU fallback at this stage.
note: &'static strShort interpretation of the counters behind this stage.