pub enum JpegToHtj2kError {
Jpeg(JpegError),
Unsupported(&'static str),
Grid(String),
Grid97(String),
Accelerator(TranscodeStageError),
Metrics(String),
Validation(&'static str),
Encode(&'static str),
}Expand description
Error returned by the experimental transcode path.
Variants
Jpeg(JpegError)
JPEG parse or entropy decode failed.
Unsupported(&'static str)
Input is outside the currently implemented experimental slice.
Grid(String)
DCT block grid metadata did not cover the component dimensions.
Grid97(String)
DCT block grid metadata did not cover the component dimensions for the 9/7 path.
Accelerator(TranscodeStageError)
Optional transform acceleration failed.
Metrics(String)
Validation metric inputs were inconsistent.
Validation(&'static str)
Validation encountered an out-of-range or non-finite coefficient.
Encode(&'static str)
Native HTJ2K encode failed.